@@ -1,5 +1,5 @@
 #define PCI_CONFIG_H
-#define PCI_ARCH_EVBARM
+#define PCI_ARCH_LANDISK
 #define PCI_OS_NETBSD
 #define PCI_HAVE_PM_NBSD_LIBPCI
 #define PCI_HAVE_PM_MMIO_CONF
@@ -15,5 +15,5 @@
 #define PCI_USE_DNS
 #define PCI_ID_DOMAIN "pci.id.ucw.cz"
 #define PCI_SHARED_LIB
-#define PCILIB_VERSION "3.13.0"
-#define PCILIB_DATE_AMIGAOS "30.05.2024"
+#define PCILIB_VERSION "3.14.0"
+#define PCILIB_DATE_AMIGAOS "21.06.2025"
